EXPORTS
	??1CContactSyncChecker@@UAE@XZ @ 1 NONAME ; CContactSyncChecker::~CContactSyncChecker(void)
	?AddContactToPhonebookL@CContactSyncChecker@@SAHVTUid@@ABVTDesC16@@1@Z @ 2 NONAME ; int CContactSyncChecker::AddContactToPhonebookL(class TUid, class TDesC16 const &, class TDesC16 const &)
	?CompleteNotificationRequestL@CContactSyncChecker@@SAXHVTUid@@@Z @ 3 NONAME ; void CContactSyncChecker::CompleteNotificationRequestL(int, class TUid)
	?DeleteContactResponseL@CContactSyncChecker@@SAHXZ @ 4 NONAME ; int CContactSyncChecker::DeleteContactResponseL(void)
	?EnableVerboseLoggingL@CContactSyncChecker@@SAXXZ @ 5 NONAME ; void CContactSyncChecker::EnableVerboseLoggingL(void)
	?FetchNotificationErrorL@CContactSyncChecker@@SAHVTUid@@@Z @ 6 NONAME ; int CContactSyncChecker::FetchNotificationErrorL(class TUid)
	?GroupIdL@CContactSyncChecker@@SAJVTUid@@@Z @ 7 NONAME ; long CContactSyncChecker::GroupIdL(class TUid)
	?ICCTemplateIdL@CContactSyncChecker@@SAJVTUid@@@Z @ 8 NONAME ; long CContactSyncChecker::ICCTemplateIdL(class TUid)
	?IsSynchronisedL@CContactSyncChecker@@QAEHVTUid@@@Z @ 9 NONAME ; int CContactSyncChecker::IsSynchronisedL(class TUid)
	?NewL@CContactSyncChecker@@SAPAV1@XZ @ 10 NONAME ; class CContactSyncChecker * CContactSyncChecker::NewL(void)
	?NotificationPendingCountL@CContactSyncChecker@@SAHVTUid@@@Z @ 11 NONAME ; int CContactSyncChecker::NotificationPendingCountL(class TUid)
	?PhonebookListL@CContactSyncChecker@@SAHAAV?$RArray@VTUid@@@@@Z @ 12 NONAME ; int CContactSyncChecker::PhonebookListL(class RArray<class TUid> &)
	?PhonebookUidL@CContactSyncChecker@@SA?AVTUid@@J@Z @ 13 NONAME ; class TUid CContactSyncChecker::PhonebookUidL(long)
	?PluginLoadedCountL@CContactSyncChecker@@SAHXZ @ 14 NONAME ; int CContactSyncChecker::PluginLoadedCountL(void)
	?PluginLoadedL@CContactSyncChecker@@SAXXZ @ 15 NONAME ; void CContactSyncChecker::PluginLoadedL(void)
	?PluginUnloadedL@CContactSyncChecker@@SAXXZ @ 16 NONAME ; void CContactSyncChecker::PluginUnloadedL(void)
	?ResetEverythingL@CContactSyncChecker@@SAXXZ @ 17 NONAME ; void CContactSyncChecker::ResetEverythingL(void)
	?ResetL@CContactSyncChecker@@SAXXZ @ 18 NONAME ; void CContactSyncChecker::ResetL(void)
	?ResetMethodCallCountsL@CContactSyncChecker@@SAXXZ @ 19 NONAME ; void CContactSyncChecker::ResetMethodCallCountsL(void)
	?ResetSyncIccAllPhonebooksL@CContactSyncChecker@@QAEHH@Z @ 20 NONAME ; int CContactSyncChecker::ResetSyncIccAllPhonebooksL(int)
	?ResetSyncIccPhonebookL@CContactSyncChecker@@QAEHVTUid@@H@Z @ 21 NONAME ; int CContactSyncChecker::ResetSyncIccPhonebookL(class TUid, int)
	?SetDeleteContactResponseL@CContactSyncChecker@@SAXH@Z @ 22 NONAME ; void CContactSyncChecker::SetDeleteContactResponseL(int)
	?SetGsmPhonebookL@CContactSyncChecker@@SAHXZ @ 23 NONAME ; int CContactSyncChecker::SetGsmPhonebookL(void)
	?SetPhonebookEntryL@CContactSyncChecker@@SAXVTUid@@HH@Z @ 24 NONAME ; void CContactSyncChecker::SetPhonebookEntryL(class TUid, int, int)
	?SetPhonebookListL@CContactSyncChecker@@SAHV?$RArray@VTUid@@@@@Z @ 25 NONAME ; int CContactSyncChecker::SetPhonebookListL(class RArray<class TUid>)
	?SetSynchronisedL@CContactSyncChecker@@SAXHVTUid@@@Z @ 26 NONAME ; void CContactSyncChecker::SetSynchronisedL(int, class TUid)
	?SetSynchronisedLeaveCodeL@CContactSyncChecker@@SAXHVTUid@@@Z @ 27 NONAME ; void CContactSyncChecker::SetSynchronisedLeaveCodeL(int, class TUid)
	?SetUsimPhonebookL@CContactSyncChecker@@SAHXZ @ 28 NONAME ; int CContactSyncChecker::SetUsimPhonebookL(void)
	?SetValidateResponseL@CContactSyncChecker@@SAXW4TValidateOperation@MContactSynchroniser@@H@Z @ 29 NONAME ; void CContactSyncChecker::SetValidateResponseL(enum MContactSynchroniser::TValidateOperation, int)
	?SetValidateWriteResponseL@CContactSyncChecker@@SAXH@Z @ 30 NONAME ; void CContactSyncChecker::SetValidateWriteResponseL(int)
	?StoreNotificationRequestL@CContactSyncChecker@@SAXAAVTRequestStatus@@VTUid@@@Z @ 31 NONAME ; void CContactSyncChecker::StoreNotificationRequestL(class TRequestStatus &, class TUid)
	?SyncMethodCallCountL@CContactSyncChecker@@SAHXZ @ 32 NONAME ; int CContactSyncChecker::SyncMethodCallCountL(void)
	?SyncMethodCalledL@CContactSyncChecker@@SAXXZ @ 33 NONAME ; void CContactSyncChecker::SyncMethodCalledL(void)
	?SynchroniseIccAllPhonebooksL@CContactSyncChecker@@SAHAAVCContactDatabase@@HH@Z @ 34 NONAME ; int CContactSyncChecker::SynchroniseIccAllPhonebooksL(class CContactDatabase &, int, int)
	?SynchroniseIccPhonebookL@CContactSyncChecker@@SAHAAVCContactDatabase@@VTUid@@HH@Z @ 35 NONAME ; int CContactSyncChecker::SynchroniseIccPhonebookL(class CContactDatabase &, class TUid, int, int)
	?TotalNotificationPendingCountL@CContactSyncChecker@@SAHXZ @ 36 NONAME ; int CContactSyncChecker::TotalNotificationPendingCountL(void)
	?UpdatePhonebookEntryL@CContactSyncChecker@@SAHVTUid@@HH@Z @ 37 NONAME ; int CContactSyncChecker::UpdatePhonebookEntryL(class TUid, int, int)
	?UpdatePhonebookGroupIdL@CContactSyncChecker@@SAHVTUid@@H@Z @ 38 NONAME ; int CContactSyncChecker::UpdatePhonebookGroupIdL(class TUid, int)
	?UpdatePhonebookTemplateIdL@CContactSyncChecker@@SAHVTUid@@H@Z @ 39 NONAME ; int CContactSyncChecker::UpdatePhonebookTemplateIdL(class TUid, int)
	?ValidateMethodCallCountL@CContactSyncChecker@@SAHXZ @ 40 NONAME ; int CContactSyncChecker::ValidateMethodCallCountL(void)
	?ValidateMethodCalledL@CContactSyncChecker@@SAXXZ @ 41 NONAME ; void CContactSyncChecker::ValidateMethodCalledL(void)
	?ValidateResponseL@CContactSyncChecker@@SAHW4TValidateOperation@MContactSynchroniser@@@Z @ 42 NONAME ; int CContactSyncChecker::ValidateResponseL(enum MContactSynchroniser::TValidateOperation)
	?ValidateWriteResponseL@CContactSyncChecker@@SAHXZ @ 43 NONAME ; int CContactSyncChecker::ValidateWriteResponseL(void)
	?VerboseLoggingEnabledL@CContactSyncChecker@@SAHXZ @ 44 NONAME ; int CContactSyncChecker::VerboseLoggingEnabledL(void)

